@@ -913,26 +913,6 @@ py_del_item <- function(x, name) {
 
 
 
-#' Unique identifer for Python object
-#'
-#' Get a globally unique identifer for a Python object.
-#'
-#' @note In the current implementation of CPython this is the
-#'  memory address of the object.
-#'
-#' @param object Python object
-#'
-#' @return Unique identifer (as integer) or `NULL`
-#'
-#' @export
-py_id <- function(object) {
-  if (py_is_null_xptr(object) || !py_available())
-    NULL
-  else {
-    py <- import_builtins()
-    py$id(object)
-  }
-}
 
 
 #' String representation of a python object.
@@ -1602,6 +1582,7 @@ py_last_error <- function(exception) {
     message = paste0(traceback$format_exception(etype, e, etb),
                      collapse = "")
   )
+  out <- lapply(out, as_r_value)
   attr(out, "exception") <- e
   class(out) <- "py_error"
   out
