@@ -6,6 +6,10 @@ run <- function() {
     return()
   }
   
+  options(error = traceback)
+  if (requireNamespace("rlang", quietly = TRUE))
+    options(error = rlang::trace_back)
+  
   library(testthat)
   library(reticulate)
   
